/**********************************************************************

 SGTSHELLFUNC.H

 Copyright (C) 1998 (e)

 Purpose:
   A singleton class used to implement program-group creation via
   shell calls.

**********************************************************************/
#ifndef SGTSHELLFUNC_H
#define SGTSHELLFUNC_H

class CSGTShellFunc
{
public:
	// Singleton creation function
	static CSGTShellFunc* Instance();
	// Singleton destruction function
	static void Destroy();

	// Function to parse an incomming DDE request
	BOOL ParseRequest(char* szRequest, char* szParameters);

	// Show a program group
	BOOL ShowGroup(LPCTSTR strGroupName, int nShow, BOOL bCommon);
	// Create a program group
	BOOL CreateGroup(LPCTSTR strGroupName, BOOL bCommon);
	// Delete a program group
	BOOL DeleteGroup(LPCTSTR strGroupName, BOOL bCommon);
	// Return a list of available program groups to the caller
	// NB: Caller is responsible for free-ing pGroupList via a
	// HeapFree() call
	BOOL ListGroups(LPVOID& pGroupList, UINT& ulSize);
	// Delete an item from the current program group
	BOOL DeleteItem(LPCTSTR strItem);
	// Add an item to the current program group
	BOOL AddItem(LPCTSTR strCmdLine, LPCTSTR pszDescription, LPCTSTR pszIconPath, int nIconIndex, LPCTSTR pszDefDir, WORD dwHotKey, BOOL bMinimize, BOOL bSepMemSpace);

	~CSGTShellFunc();

protected:
	// Get the path to the relevant program-group's folder
	BOOL GetProgramsPath(BOOL bCommon, char* szPath);
	// Helper function to collect a list of groups (directories) from a path
	BOOL ListGroupsHelper(HANDLE hHeap, char* szPath, LPVOID& pGroupList, UINT& ulSize);

	static CSGTShellFunc* m_pCSGTShellFunc;
	CSGTShellFunc();

	// The currently selected group. Set by a call to
	// CreateGroup() or ShowGroup() and used in
	// DeleteItem() and AddItem()
	char m_szCurrentGroup[MAX_PATH];

	// Boolean set on creation to determine if the user is an admin.
	// Essential for determining which group (common or local) should
	// be used when it is not specified by the DDE string.
	BOOL m_bIsUserAnAdmin;

	FARPROC (__stdcall *SHFindFiles)(LPCITEMIDLIST, LPCITEMIDLIST);
};

#endif //SGTSHELLFUNC_H

